@@ -52,10 +52,14 @@ static void     gpm_dpms_finalize   (GObject      *object);
 
 #define GPM_DPMS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_DPMS, GpmDpmsPrivate))
 
+/* until we get a nice event-emitting DPMS extension, we have to poll... */
+#define GPM_DPMS_POLL_TIME	10*1000
+
 struct GpmDpmsPrivate
 {
 	gboolean		 enabled;
 	gboolean		 active;
+	gboolean		 dpms_capable;
 
 	guint			 standby_timeout;
 	guint			 suspend_timeout;
@@ -76,10 +80,10 @@ enum {
 	PROP_0,
 	PROP_STANDBY_TIMEOUT,
 	PROP_SUSPEND_TIMEOUT,
-	PROP_OFF_TIMEOUT,
+	PROP_OFF_TIMEOUT
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_dpms_object = NULL;
 
 G_DEFINE_TYPE (GpmDpms, gpm_dpms, G_TYPE_OBJECT)
@@ -116,37 +120,15 @@ x11_sync_server_dpms_settings (Display *dpy,
 			       GError **error)
 {
 #ifdef HAVE_DPMS_EXTENSION
-
-	int	 event = 0;
-	int      err = 0;
-	BOOL	 o_enabled = FALSE;
-	CARD16	 o_power = 0;
-	CARD16	 o_standby = 0;
-	CARD16   o_suspend = 0;
-	CARD16   o_off = 0;
+	BOOL o_enabled = FALSE;
+	CARD16 o_power = 0;
+	CARD16 o_standby = 0;
+	CARD16 o_suspend = 0;
+	CARD16 o_off = 0;
 
 	gpm_debug ("Syncing DPMS settings enabled=%d timeouts=%d %d %d",
 		   enabled, standby_secs, suspend_secs, off_secs);
 
-	if (! DPMSQueryExtension (dpy, &event, &err)) {
-		gpm_debug ("XDPMS extension not supported");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "DPMS extension not supported");
-		return FALSE;
-	}
-
-	if (! DPMSCapable (dpy)) {
-		gpm_debug ("Display is not DPMS capable");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "Display is not DPMS capable");
-
-		return FALSE;
-	}
-
 	if (! DPMSInfo (dpy, &o_power, &o_enabled)) {
 		gpm_debug ("unable to get DPMS state.");
 		g_set_error (error,
@@ -222,19 +204,12 @@ x11_get_mode (GpmDpms     *dpms,
 	      GError     **error)
 {
 	GpmDpmsMode result;
-	int	    event_number;
-	int	    error_number;
-	BOOL	    enabled = FALSE;
-	CARD16	    state;
+	BOOL enabled = FALSE;
+	CARD16 state;
 
-	if (! DPMSQueryExtension (GDK_DISPLAY (), &event_number, &error_number)) {
-		/* Server doesn't know -- assume the monitor is on. */
+	if (dpms->priv->dpms_capable == FALSE) {
+		/* Server or monitor can't DPMS -- assume the monitor is on. */
 		result = GPM_DPMS_MODE_ON;
-
-	} else if (! DPMSCapable (GDK_DISPLAY ())) {
-		/* Server says the monitor doesn't do power management -- so it's on. */
-		result = GPM_DPMS_MODE_ON;
-
 	} else {
 		DPMSInfo (GDK_DISPLAY (), &state, &enabled);
 		if (! enabled) {
@@ -274,22 +249,11 @@ x11_set_mode (GpmDpms	 *dpms,
 	      GError    **error)
 {
 	GpmDpmsMode current_mode;
-	CARD16	    state;
-	CARD16	    current_state;
-	BOOL	    current_enabled;
-	int	    event_number;
-	int	    error_number;
+	CARD16 state;
+	CARD16 current_state;
+	BOOL current_enabled;
 
-	if (! DPMSQueryExtension (GDK_DISPLAY (), &event_number, &error_number)) {
-		gpm_debug ("unable to query DPMS extention");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "DPMS extension not supported");
-		return FALSE;
-	}
-
-	if (! DPMSCapable (GDK_DISPLAY ())) {
+	if (dpms->priv->dpms_capable == FALSE) {
 		gpm_debug ("not DPMS capable");
 		g_set_error (error,
 			     GPM_DPMS_ERROR,
@@ -393,6 +357,16 @@ sync_settings (GpmDpms *dpms,
 		off     = 0;
 	}
 
+	if (dpms->priv->dpms_capable == FALSE) {
+		gpm_debug ("Display is not DPMS capable");
+		g_set_error (error,
+			     GPM_DPMS_ERROR,
+			     GPM_DPMS_ERROR_GENERAL,
+			     "Display is not DPMS capable");
+
+		return FALSE;
+	}
+
 	/* We always try to keep the DPMS enabled so that
 	   we can use set the mode manually.  We will
 	   use zero values for the timeouts when the
@@ -812,7 +786,10 @@ gpm_dpms_init (GpmDpms *dpms)
 {
 	dpms->priv = GPM_DPMS_GET_PRIVATE (dpms);
 
-	add_poll_timer (dpms, 500);
+	/* DPMSCapable() can never change for a given display */
+	dpms->priv->dpms_capable = DPMSCapable (GDK_DISPLAY ());
+
+	add_poll_timer (dpms, GPM_DPMS_POLL_TIME);
 }
 
 static void
