@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
- * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2008 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -30,9 +30,8 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#if HAVE_GTKUNIQUE
-#include <gtkunique/gtkunique.h>
-#endif
+/* local .la */
+#include <libunique.h>
 
 #include "gpm-common.h"
 #include "gpm-prefs.h"
@@ -60,32 +59,20 @@ gpm_prefs_help_cb (GpmPrefs *prefs)
 static void
 gpm_prefs_close_cb (GpmPrefs *prefs)
 {
-	g_object_unref (prefs);
-	exit (0);
+	gtk_main_quit ();
 }
 
-#if HAVE_GTKUNIQUE
 /**
- * gtkuniqueapp_command_cb:
+ * gpm_prefs_activated_cb
+ * @prefs: This prefs class instance
+ *
+ * We have been asked to show the window
  **/
 static void
-gtkuniqueapp_command_cb (GtkUniqueApp    *app,
-		         GtkUniqueCommand command,
-		         const gchar     *data,
-		         const gchar     *startup_id,
-		         GdkScreen	 *screen,
-		         guint            workspace,
-		         gpointer         user_data)
+gpm_prefs_activated_cb (LibUnique *libunique, GpmPrefs *prefs)
 {
-	GpmPrefs *prefs;
-
-	gpm_debug ("GtkUnique message %i", command);
-	prefs = GPM_PREFS (user_data);
-	if (command == GTK_UNIQUE_ACTIVATE) {
-		gpm_prefs_activate_window (prefs);
-	}
+	gpm_prefs_activate_window (prefs);
 }
-#endif
 
 /**
  * main:
@@ -96,11 +83,8 @@ main (int argc, char **argv)
 	gboolean verbose = FALSE;
 	GOptionContext *context;
 	GpmPrefs *prefs = NULL;
-	GMainLoop *loop;
-#if HAVE_GTKUNIQUE
-	GtkUniqueApp *uniqueapp;
-	const gchar *startup_id = NULL;
-#endif
+	gboolean ret;
+	LibUnique *libunique;
 
 	const GOptionEntry options[] = {
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
@@ -115,15 +99,6 @@ main (int argc, char **argv)
 	textdomain (GETTEXT_PACKAGE);
 
 	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
-
-#if HAVE_GTKUNIQUE
-	/* FIXME: We don't need to get the startup id once we can
-	 * depend on gtk+-2.12.  Until then we must get it BEFORE
-	 * gtk_init() is called, otherwise gtk_init() will clear it
-	 * and GtkUnique has to use racy workarounds.
-	 */
-	startup_id = g_getenv ("DESKTOP_STARTUP_ID");
-#endif
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (FALSE));
 	g_option_context_parse (context, &argc, &argv, NULL);
@@ -131,53 +106,28 @@ main (int argc, char **argv)
 	gtk_init (&argc, &argv);
 	gpm_debug_init (verbose);
 
-#if HAVE_GTKUNIQUE
-	gpm_debug ("Using GtkUnique support.");
-
-	/* Arrr! Until we depend on gtk+2 2.12 we can't just use gtk_unique_app_new */
-	uniqueapp = gtk_unique_app_new_with_id ("org.freedesktop.PowerManagement.Preferences", startup_id);
-	/* check to see if the user has another prefs window open */
-	if (gtk_unique_app_is_running (uniqueapp)) {
-		gpm_warning ("You have another instance running. "
-			     "This program will now close");
-		gtk_unique_app_activate (uniqueapp);
-
-		/* FIXME: This next line should be removed once we can depend
-		 * upon gtk+-2.12.  This causes the busy cursor and temporary
-		 * task in the tasklist to go away too soon (though that's
-		 * better than having them be stuck until the 30-second-or-so
-		 * timeout ends).
-		 */
-		gdk_notify_startup_complete ();
-	} else {
-#else
-	gpm_warning ("No GtkUnique support. Cannot signal other instances");
-	/* we always assume we have no other running instance */
-	if (1) {
-#endif
-		/* create a new instance of the window */
-		prefs = gpm_prefs_new ();
-
-		g_signal_connect (prefs, "action-help",
-				  G_CALLBACK (gpm_prefs_help_cb), prefs);
-		g_signal_connect (prefs, "action-close",
-				  G_CALLBACK (gpm_prefs_close_cb), prefs);
-#if HAVE_GTKUNIQUE
-		/* Listen for messages from another instances */
-		g_signal_connect (G_OBJECT (uniqueapp), "message",
-				  G_CALLBACK (gtkuniqueapp_command_cb), prefs);
-#endif
-		loop = g_main_loop_new (NULL, FALSE);
-		g_main_loop_run (loop);
-
-		g_object_unref (prefs);
+	/* are we already activated? */
+	libunique = libunique_new ();
+	ret = libunique_assign (libunique, "org.freedesktop.PowerManagement.Preferences");
+	if (!ret) {
+		goto unique_out;
 	}
 
+	prefs = gpm_prefs_new ();
+
+	g_signal_connect (libunique, "activated",
+			  G_CALLBACK (gpm_prefs_activated_cb), prefs);
+	g_signal_connect (prefs, "action-help",
+			  G_CALLBACK (gpm_prefs_help_cb), prefs);
+	g_signal_connect (prefs, "action-close",
+			  G_CALLBACK (gpm_prefs_close_cb), prefs);
+	gtk_main ();
+	g_object_unref (prefs);
+
+unique_out:
 	gpm_debug_shutdown ();
+	g_object_unref (libunique);
 
-#if HAVE_GTKUNIQUE
-	g_object_unref (uniqueapp);
-#endif
 /* seems to not work...
 	g_option_context_free (context); */
 
