@@ -83,16 +83,16 @@ conf_key_changed_cb (GpmConf          *conf,
 
 	on_ac = gpm_ac_adapter_is_present (srv_brightness->priv->ac_adapter);
 
-	if (strcmp (key, GPM_CONF_AC_BRIGHTNESS_KBD) == 0) {
+	if (strcmp (key, GPM_CONF_KEYBOARD_BRIGHTNESS_AC) == 0) {
 
-		gpm_conf_get_int (srv_brightness->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
+		gpm_conf_get_int (srv_brightness->priv->conf, GPM_CONF_KEYBOARD_BRIGHTNESS_AC, &value);
 		if (on_ac == TRUE) {
 			gpm_brightness_kbd_set_std (srv_brightness->priv->brightness, value);
 		}
 
-	} else if (strcmp (key, GPM_CONF_BATT_BRIGHTNESS_KBD) == 0) {
+	} else if (strcmp (key, GPM_CONF_KEYBOARD_BRIGHTNESS_BATT) == 0) {
 
-		gpm_conf_get_int (srv_brightness->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
+		gpm_conf_get_int (srv_brightness->priv->conf, GPM_CONF_KEYBOARD_BRIGHTNESS_AC, &value);
 		if (on_ac == FALSE) {
 			gpm_brightness_kbd_set_std (srv_brightness->priv->brightness, value);
 		}
@@ -116,9 +116,9 @@ ac_adapter_changed_cb (GpmAcAdapter      *ac_adapter,
 	guint value;
 
 	if (on_ac == TRUE) {
-		gpm_conf_get_uint (srv_brightness->priv->conf, GPM_CONF_AC_BRIGHTNESS_KBD, &value);
+		gpm_conf_get_uint (srv_brightness->priv->conf, GPM_CONF_KEYBOARD_BRIGHTNESS_AC, &value);
 	} else {
-		gpm_conf_get_uint (srv_brightness->priv->conf, GPM_CONF_BATT_BRIGHTNESS_KBD, &value);
+		gpm_conf_get_uint (srv_brightness->priv->conf, GPM_CONF_KEYBOARD_BRIGHTNESS_BATT, &value);
 	}
 
 	gpm_brightness_kbd_set_std (srv_brightness->priv->brightness, value);
@@ -141,7 +141,7 @@ button_pressed_cb (GpmButton        *button,
 	if ((strcmp (type, GPM_BUTTON_KBD_BRIGHT_UP) == 0)) {
 		gpm_brightness_kbd_up (srv_brightness->priv->brightness);
 
-	} else if ((strcmp (type, GPM_BUTTON_KBD_BRIGHT_UP) == 0)) {
+	} else if ((strcmp (type, GPM_BUTTON_KBD_BRIGHT_DOWN) == 0)) {
 		gpm_brightness_kbd_down (srv_brightness->priv->brightness);
 
 	} else if (strcmp (type, GPM_BUTTON_KBD_BRIGHT_TOGGLE) == 0) {
